@@ -1047,7 +1047,8 @@ class TestImpersonatedCredentials(object):
         id_creds.refresh(request)
 
         assert id_creds.token == ID_TOKEN_DATA
-        assert id_creds.expiry == datetime.datetime.utcfromtimestamp(ID_TOKEN_EXPIRY)
+        expected_expiry = _helpers.utcfromtimestamp(ID_TOKEN_EXPIRY)
+        assert id_creds.expiry == expected_expiry
 
     def test_id_token_metrics(self, mock_donor_credentials):
         credentials = self.make_credentials(lifetime=None)
@@ -1071,9 +1072,8 @@ class TestImpersonatedCredentials(object):
                 id_creds.refresh(None)
 
                 assert id_creds.token == ID_TOKEN_DATA
-                assert id_creds.expiry == datetime.datetime.utcfromtimestamp(
-                    ID_TOKEN_EXPIRY
-                )
+                expected_expiry = _helpers.utcfromtimestamp(ID_TOKEN_EXPIRY)
+                assert id_creds.expiry == expected_expiry
                 assert (
                     mock_post.call_args.kwargs["headers"]["x-goog-api-client"]
                     == ID_TOKEN_REQUEST_METRICS_HEADER_VALUE
@@ -1181,7 +1181,8 @@ class TestImpersonatedCredentials(object):
         id_creds.refresh(request)
 
         assert id_creds.token == ID_TOKEN_DATA
-        assert id_creds.expiry == datetime.datetime.utcfromtimestamp(ID_TOKEN_EXPIRY)
+        expected_expiry = _helpers.utcfromtimestamp(ID_TOKEN_EXPIRY)
+        assert id_creds.expiry == expected_expiry
         assert id_creds._include_email is True
 
     def test_id_token_invalid_cred(
